@@ -1,4 +1,4 @@
-from lib.blocks.base import Base
+from one_block.base import Base
 
 
 class Accessory(Base):
