@@ -1,5 +1,5 @@
-from lib.blocks import base
-from lib.blocks.accessory import Accessory
+from one_block import base
+from one_block.accessory import Accessory
 
 
 class Button(Accessory):
