@@ -1,4 +1,4 @@
-from lib.blocks.accessory import Accessory
+from one_block.accessory import Accessory
 
 
 class Checkbox(Accessory):
