@@ -1,5 +1,5 @@
-from lib.blocks.accessory import Accessory
-from lib.blocks.base import BasePlainText, BaseMarkdown
+from one_block.accessory import Accessory
+from one_block.base import BasePlainText, BaseMarkdown
 
 
 class Option(Accessory):
