@@ -1,6 +1,6 @@
 from typing import List
 
-from lib.blocks.accessory import Accessory, Option
+from one_block.accessory import Accessory, Option
 
 
 class RadioButtons(Accessory):
