@@ -1,5 +1,5 @@
-from lib.blocks.base import Base, BasePlainText
-from lib.blocks.input_blocks.plain_text_input import PlainTextInput
+from one_block.base import Base, BasePlainText
+from one_block.input_blocks.plain_text_input import PlainTextInput
 
 
 class TextInput(Base):
