@@ -1,5 +1,5 @@
-from lib.blocks import accessory
-from lib.blocks.base import Base, BaseMarkdown
+from one_block import accessory
+from one_block.base import Base, BaseMarkdown
 
 
 class Button(Base):
