@@ -1,6 +1,6 @@
-from lib.blocks import base
-from lib.blocks import image
-from lib.blocks.base import Base
+from one_block import base
+from one_block import image
+from one_block.base import Base
 
 
 class Image(Base):
