@@ -1,4 +1,4 @@
-from lib.blocks.base import Base, BaseMarkdown
+from one_block.base import Base, BaseMarkdown
 
 
 class Markdown(Base):
