@@ -1,4 +1,4 @@
-from lib.blocks.base import Base, BasePlainText
+from one_block.base import Base, BasePlainText
 
 
 class PlainText(Base):
