@@ -1,6 +1,6 @@
 from typing import List
 
-from lib.blocks.base import Base
+from one_block.base import Base
 
 
 class TextFields(Base):
